package com.sensor.iot.api.enums;

import cn.hutool.core.util.StrUtil;
import lombok.Getter;
import lombok.RequiredArgsConstructor;

/**
 * ApiEnum
 *
 * @author Frank
 */
@Getter
@RequiredArgsConstructor
public enum ApiEnum {

    /**
     * 获取token
     */
    TOKEN("/auth/oauth2/client_token"),

    /**
     * 添加设备
     */
    DEVICE_CREATE("/iot/api/device/add"),

    /**
     * 更新设备
     */
    DEVICE_UPDATE("/iot/api/device/edit"),

    /**
     * 设备信息 / 设备删除
     */
    SINGLE_DEVICE_OPT("/iot/api/device/{}"),

    /**
     * 设备属性操作
     */
    DEVICE_PROP_OPT("/iot/api/opt/device/properties"),

    /**
     * 设备执行功能
     */
    DEVICE_FUNC_INVOKE("/iot/api/opt/device/function"),

    /**
     * 下发自定义消息
     */
    SEND_CUSTOM_MSG("/iot/api/opt/device/sendMsg"),

    /**
     * 获取设备物模型属性配置
     */
    DEVICE_TSL_PROP("/iot/api/tsl/{}/prop"),

    /**
     * 获取设备物模型事件配置
     */
    DEVICE_TSL_EVENT("/iot/api/tsl/{}/event"),

    /**
     * 获取设备物模型功能配置
     */
    DEVICE_TSL_FUNC("/iot/api/tsl/{}/func"),

    /**
     * 查询指定设备属性值
     */
    TSL_PROP("/iot/api/tsl/prop"),

    /**
     * 查询指定设备最新属性数据
     */
    TSL_PROP_LATEST("/iot/api/tsl/prop/latest"),

    /**
     * 查询设备属性历史数据
     */
    TSL_PROP_HISTORY("/iot/api/tsl/propHistory"),

    /**
     * 查询设备事件历史数据
     */
    TSL_EVENT_HISTORY("/iot/api/tsl/eventHistory"),

    /**
     * 查询设备功能操作历史
     */
    TSL_FUNC_HISTORY("/iot/api/tsl/func/history"),

    ;


    private final String path;

    /**
     * 组合url
     *
     * @param baseUrl    主域名
     * @param pathParams path参数
     * @return 完整url
     */
    public String url(String baseUrl, Object... pathParams) {
        return baseUrl + StrUtil.format(path, pathParams);
    }
}
