package com.sensor.iot.api.interceptor;

import cn.hutool.http.HttpInterceptor;
import cn.hutool.http.HttpRequest;
import com.sensor.iot.api.config.SensorIotApiProperties;
import com.sensor.iot.api.model.ApiResp;
import com.sensor.iot.api.model.ClientToken;
import com.sensor.iot.api.service.ClientTokenService;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import java.util.concurrent.TimeUnit;

/**
 * AuthInterceptor
 *
 * @author Frank
 */
@Setter
@Component
@RequiredArgsConstructor
public class AuthInterceptor implements HttpInterceptor<HttpRequest> {
    private final ClientTokenService clientTokenService;
    private final RedisTemplate<String, String> redisTemplate;
    private final SensorIotApiProperties apiProperties;

    @Override
    public void process(HttpRequest httpRequest) {
        httpRequest.header("Authorization", tokenCache());
    }

    private String tokenCache() {
        String key = "client:token:" + apiProperties.getClientId();
        String token = redisTemplate.opsForValue().get(key);
        if (token != null) {
            return token;
        }
        ApiResp<ClientToken> tokenApiResp = clientTokenService.getAuthToken(apiProperties.getClientId(), apiProperties.getClientSecret());
        token = tokenApiResp.data().getClientToken();
        redisTemplate.opsForValue().set(key, token, 6900, TimeUnit.SECONDS);
        return token;
    }
}
