package com.sensor.iot.api.service;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.TypeReference;
import com.sensor.iot.api.config.SensorIotApiProperties;
import com.sensor.iot.api.enums.ApiEnum;
import com.sensor.iot.api.model.ApiResp;
import com.sensor.iot.api.model.ClientToken;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

/**
 * ClientTokenService
 *
 * @author Frank
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class ClientTokenService {

    private final SensorIotApiProperties apiProperties;

    /**
     * 获取token
     *
     * @param clientId     clientId
     * @param clientSecret clientSecret
     * @param grantType    grantType
     * @return {@link ApiResp}
     */
    public ApiResp<ClientToken> getAuthToken(String clientId, String clientSecret, String grantType) {

        Map<String, Object> params = new HashMap<>();
        params.put("client_id", clientId);
        params.put("client_secret", clientSecret);
        params.put("grant_type", grantType);
        try (HttpResponse response = HttpRequest.get(ApiEnum.TOKEN.url(apiProperties.getBaseUrl()))
                .timeout(apiProperties.getTimeout())
                .form(params)
                .execute()
        ) {
            String resp = response.body();
            return JSONObject.parseObject(resp, new TypeReference<ApiResp<ClientToken>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("获取auth_token失败:" + ex.getMessage());
        }
    }

    public ApiResp<ClientToken> getAuthToken(String clientId, String clientSecret) {
        return getAuthToken(clientId, clientSecret, "client_credentials");
    }
}
