package com.sensor.iot.api.service;

import com.sensor.iot.api.model.ApiResp;
import com.sensor.iot.api.model.PropQuery;
import com.sensor.iot.api.model.QueryResp;
import com.sensor.iot.api.model.TslHistoryQuery;

import java.util.List;
import java.util.Map;

/**
 * DeviceTslApiService
 *
 * @author Frank
 */
public interface DeviceTslApiService {

    /**
     * 获取设备物模型属性配置
     *
     * @param deviceId 设备编号
     * @return {@link ApiResp}
     */
    ApiResp<List<Map<String, Object>>> deviceProp(String deviceId);

    /**
     * 根据标识符查找设备物模型属性配置
     *
     * @param deviceId 设备编号
     * @param identity 属性标识符
     * @return {@link ApiResp}
     */
    ApiResp<Map<String, Object>> deviceProp(String deviceId, String identity);

    /**
     * 获取设备物模型事件配置
     *
     * @param deviceId 设备编号
     * @return {@link ApiResp}
     */
    ApiResp<List<Map<String, Object>>> deviceEvent(String deviceId);

    /**
     * 根据事件标识符获取设备物模型事件配置
     *
     * @param deviceId 设备编号
     * @param identity 事件标识符
     * @return {@link ApiResp}
     */
    ApiResp<Map<String, Object>> deviceEvent(String deviceId, String identity);

    /**
     * 获取设备物模型功能配置
     *
     * @param deviceId 设备编号
     * @return {@link ApiResp}
     */
    ApiResp<List<Map<String, Object>>> deviceFunc(String deviceId);

    /**
     * 根据功能标识符获取设备物模型功能配置
     *
     * @param deviceId 设备编号
     * @param identity 功能标识符
     * @return {@link ApiResp}
     */
    ApiResp<Map<String, Object>> deviceFunc(String deviceId, String identity);

    /**
     * 查询指定设备属性值
     *
     * @param query {@link PropQuery}
     * @return {@link ApiResp}
     */
    ApiResp<Map<String, Object>> queryProp(PropQuery query);

    /**
     * 查询指定设备最新属性数据
     *
     * @param deviceId 设备编号
     * @return {@link ApiResp}
     */
    ApiResp<Map<String, Object>> queryPropLatest(String deviceId);


    /**
     * 查询设备属性历史数据
     *
     * @param query {@link TslHistoryQuery}
     * @return {@link QueryResp}
     */
    QueryResp<Map<String, Object>> queryPropHistory(TslHistoryQuery query);

    /**
     * 查询设备事件历史数据
     *
     * @param query {@link TslHistoryQuery}
     * @return {@link QueryResp}
     */
    QueryResp<Map<String, Object>> queryEventHistory(TslHistoryQuery query);

    /**
     * 查询设备功能操作历史
     *
     * @param query {@link TslHistoryQuery}
     * @return {@link QueryResp}
     */
    QueryResp<Map<String, Object>> queryFuncHistory(TslHistoryQuery query);

}
