package com.sensor.iot.api.service.impl;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.TypeReference;
import com.sensor.iot.api.config.SensorIotApiProperties;
import com.sensor.iot.api.enums.ApiEnum;
import com.sensor.iot.api.interceptor.AuthInterceptor;
import com.sensor.iot.api.model.ApiResp;
import com.sensor.iot.api.model.DeviceReq;
import com.sensor.iot.api.service.DeviceApiService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * DeviceApiServiceImpl
 *
 * @author Frank
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class DeviceApiServiceImpl implements DeviceApiService {
    private final SensorIotApiProperties apiProperties;
    private final AuthInterceptor authInterceptor;

    @Override
    public ApiResp<Map<String, Object>> createDevice(DeviceReq params) {
        try (HttpResponse response = HttpRequest.post(ApiEnum.DEVICE_CREATE.url(apiProperties.getBaseUrl()))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .body(JSONObject.toJSONString(params))
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]创建设备API错误:" + ex.getMessage());
        }
    }

    @Override
    public ApiResp<Map<String, Object>> updateDevice(DeviceReq params) {
        try (HttpResponse response = HttpRequest.put(ApiEnum.DEVICE_UPDATE.url(apiProperties.getBaseUrl()))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .body(JSONObject.toJSONString(params))
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]更新设备API错误:" + ex.getMessage());
        }
    }

    @Override
    public ApiResp<Map<String, Object>> queryInfo(String deviceId) {
        try (HttpResponse response = HttpRequest.get(ApiEnum.SINGLE_DEVICE_OPT.url(apiProperties.getBaseUrl(), deviceId))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]查询设备详情API错误:" + ex.getMessage());
        }
    }

    @Override
    public ApiResp<Map<String, Object>> deleteDevice(String deviceId) {
        try (HttpResponse response = HttpRequest.delete(ApiEnum.SINGLE_DEVICE_OPT.url(apiProperties.getBaseUrl(), deviceId))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]删除设备API错误:" + ex.getMessage());
        }
    }
}
