package com.sensor.iot.api.service.impl;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.TypeReference;
import com.sensor.iot.api.config.SensorIotApiProperties;
import com.sensor.iot.api.enums.ApiEnum;
import com.sensor.iot.api.interceptor.AuthInterceptor;
import com.sensor.iot.api.model.*;
import com.sensor.iot.api.service.DeviceOptApiService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * DeviceOptApiServiceImpl
 *
 * @author Frank
 */
@Slf4j
@Component
@RequiredArgsConstructor
public class DeviceOptApiServiceImpl implements DeviceOptApiService {
    private final SensorIotApiProperties apiProperties;
    private final AuthInterceptor authInterceptor;

    @Override
    public ApiResp<Map<String, Object>> readProperty(ReadPropReq params) {
        try (HttpResponse response = HttpRequest.post(ApiEnum.DEVICE_PROP_OPT.url(apiProperties.getBaseUrl()))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .body(JSONObject.toJSONString(params))
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]读取设备属性API错误:" + ex.getMessage());
        }
    }

    @Override
    public ApiResp<Map<String, Object>> writeProperty(WritePropReq params) {
        try (HttpResponse response = HttpRequest.put(ApiEnum.DEVICE_PROP_OPT.url(apiProperties.getBaseUrl()))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .body(JSONObject.toJSONString(params))
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]下发设备属性API错误:" + ex.getMessage());
        }
    }

    @Override
    public ApiResp<Map<String, Object>> sendMsg(SendMsgReq params) {
        try (HttpResponse response = HttpRequest.post(ApiEnum.SEND_CUSTOM_MSG.url(apiProperties.getBaseUrl()))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .body(JSONObject.toJSONString(params))
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]下发自定义消息API错误:" + ex.getMessage());
        }
    }

    @Override
    public ApiResp<Map<String, Object>> funcInvoke(ExecFuncReq params) {
        try (HttpResponse response = HttpRequest.post(ApiEnum.DEVICE_FUNC_INVOKE.url(apiProperties.getBaseUrl()))
                .addInterceptor(authInterceptor)
                .timeout(apiProperties.getTimeout())
                .body(JSONObject.toJSONString(params))
                .execute()
        ) {
            String result = response.body();
            return JSONObject.parseObject(result, new TypeReference<ApiResp<Map<String, Object>>>() {
            });
        } catch (Exception ex) {
            throw new RuntimeException("[IOT]执行设备功能API错误:" + ex.getMessage());
        }
    }
}
